<?php

namespace TotalSurvey\Extensions\FieldsPack\Blocks;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Blocks\BlockType;
use TotalSurvey\Blocks\Concerns\GenerateInputName;
use TotalSurvey\Exceptions\Files\FileUploadException;
use TotalSurvey\Models\Block;
use TotalSurvey\Models\Entry;
use TotalSurvey\Models\EntrySection;
use TotalSurvey\Models\Validation;
use TotalSurvey\Plugin;
use TotalSurvey\Validations\DefaultValidationRules;
use TotalSurveyVendors\TotalSuite\Foundation\Helpers\Html;

class File extends BlockType
{
    public static $category = 'question';
    public static $id       = 'file';
    public static $icon     = 'subject';
    public static $static   = false;
    public static $aliases  = ['file'];

    use GenerateInputName;

    public static function render(Block $block)
    {
        $placeholder = $block->option('placeholder', __('Upload your file', 'totalsurvey'));
        $button      = Html::create(
            'button',
            ['class' => 'totalsurvey-file-button button', 'type' => 'button'],
            __('Choose', 'totalsurvey')
        );
        $input       = Html::create(
            'input',
            [
                'type'        => 'file',
                'name'        => static::getInputName($block->section->uid, $block->uid),
                'id'          => $block->uid,
                'class'       => $block->option('cssClass'),
                'placeholder' => $block->option('placeholder'),
                'ref'         => 'file',
                'v-file'     => "'{$placeholder}'",
            ]
        );
        $text        = Html::create('span', ['class' => 'totalsurvey-file-label', 'ref' => 'label'], $placeholder);
        $label       = Html::create('label', ['class' => 'totalsurvey-file'], [$text, $button, $input]);

        return $label;
    }

    public static function getValidationRules(Block $block)
    {
        $rules = parent::getValidationRules($block);
        if ($block->field->isRequired()) {
            $rules[$block->uid][] = DefaultValidationRules::file(Validation::from());
        }

        return $rules;
    }

    public static function getValidationMessages(Block $block)
    {
        return [
            "{$block->uid}:max" => str_replace(
                ['{{max}}'],
                [':max'],
                __('Maximum allowed file size is {{max}}', 'totalsurvey')
            ),
        ];
    }

    public static function getEntryBlockFromRawValue($file, Block $block, EntrySection $entrySection, Entry $entry)
    {
        $entryBlock = parent::getEntryBlockFromRawValue($file, $block, $entrySection, $entry);

        if (empty($file)) {
            $entryBlock->value = '';
            $entryBlock->text  = '';

            return $entryBlock;
        }

        $filterDir = static function ($dirs) use ($entry) {
            $uploads = Plugin::env('path.userUploads');
            $url     = Plugin::env('url.userUploads.base');

            $dirs['subdir'] = sprintf("%s/%s", $entry->survey_uid, $entry->uid);
            $dirs['path']   = sprintf("%s/%s", $uploads, $dirs['subdir']);
            $dirs['url']    = sprintf("%s/%s/%s", $url, $entry->survey_uid, $entry->uid);

            return $dirs;
        };

        add_filter('upload_dir', $filterDir);
        $file = wp_handle_upload($file, ['test_form' => false]);
        remove_filter('upload_dir', $filterDir);

        if (!empty($file['error'])) {
            FileUploadException::throw(__('File could not be stored'), [$file['error']]);
        }

        $entryBlock->value = $entryBlock->text = $file['url'];

        return $entryBlock;
    }

    public static function getMetadataFromRawValue(Block $block, Entry $entry, $value)
    {
        return [
            'size' => $value['size'] ?? 0,
            'type' => $value['type'] ?? 'application/unknown',
        ];
    }
}
