<?php

namespace TotalSurvey\Extensions\FieldsPack\Blocks;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Blocks\BlockType;
use TotalSurvey\Blocks\Concerns\GenerateInputName;
use TotalSurvey\Models\Block;
use TotalSurvey\Models\Entry;
use TotalSurvey\Models\Validation;
use TotalSurveyVendors\TotalSuite\Foundation\Helpers\Html;

class ImageChoices extends BlockType
{
    public static $category  = 'question';
    public static $id        = 'image-choice';
    public static $icon      = 'subject';
    public static $static    = false;
    public static $aggregate = true;
    public static $aliases   = ['image-choice'];

    use GenerateInputName;

    public static function render(Block $block)
    {
        $wrapper = Html::create('div', ['class' => 'totalsurvey-images-choices']);
        $options = $block->option('choices', []);

        foreach ($options as $index => $option) {
            $input = Html::create(
                'input',
                [
                    'type'                => 'radio',
                    'name'                => static::getInputName($block->section->uid, $block->uid),
                    'id'                  => $option['uid'],
                    'class'               => $block->option('cssClass'),
                    'value'               => $option['uid'],
                    'data-variable-name'  => $block->uid,
                    'data-variable-value' => $option['label'],
                ]
            );

            $choice = Html::create(
                'div',
                ['class' => 'totalsurvey-image-choice'],
                [
                    Html::create('img', ['src' => $option['url'] ?? '']),
                    Html::create('label', [], $option['label'] ?? ''),
                ]
            );

            $container = Html::create('div', ['class' => 'totalsurvey-image-container']);
            $container->addContent($input)
                      ->addContent($choice);

            $wrapper->addContent($container);
        }

        return $wrapper;
    }

    public static function getValidationRules(Block $block)
    {
        if ($block->field->isRequired()) {
            $block->field->validations->set(
                'inArray',
                Validation::from(
                    [
                        'enabled' => true,
                        'options' => [
                            'values' => $block->field->getChoicesAttribute('uid'),
                        ],
                    ]
                )
            );
        }

        return parent::getValidationRules($block);
    }

    public static function getValidationMessages(Block $block)
    {
        return [
            "{$block->uid}:in_array" => str_replace(
                ['{{allowedValues}}'],
                [implode(', ', $block->field->getChoicesAttribute('label'))],
                __('Must be one of: {{allowedValues}}', 'totalsurvey')
            ),
        ];
    }

    public static function getSerializedFromRawValue(Block $block, Entry $entry, $value)
    {
        return $value;
    }

    public static function getTextFromRawValue(Block $block, Entry $entry, $value)
    {
        $value   = (array) $value;
        $choices = $block->field->getChoicesAttribute('label', 'uid');

        foreach ($value as $index => $subValue) {
            if (isset($choices[$subValue])) {
                $value[$index] = esc_html($choices[$subValue]);
            } else {
                $value[$index] = sprintf(__('Other: %s', 'totalsurvey'), esc_html($subValue));
            }
        }

        return implode(', ', (array) $value);
    }

    public static function getTranslatableAttributes()
    {
        return [
            'field.options.choices.label',
        ];
    }
}
