<?php

namespace TotalSurvey\Extensions\FieldsPack\Blocks;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Blocks\BlockType;
use TotalSurvey\Blocks\Concerns\GenerateInputName;
use TotalSurvey\Models\Block;
use TotalSurvey\Models\Entry;
use TotalSurvey\Models\EntrySection;
use TotalSurveyVendors\TotalSuite\Foundation\Helpers\Html;
use TotalSurveyVendors\TotalSuite\Foundation\Support\Arrays;

class Rating extends BlockType
{
    public static $category  = 'question';
    public static $id        = 'rating';
    public static $icon      = 'subject';
    public static $static    = false;
    public static $aggregate = true;
    public static $symbols   = [
        'faces'  => ['🙁', '😐', '🙂', '😀', '😍'],
        'stars'  => ['️⭐️', '️⭐️', '️⭐️', '️⭐️', '️⭐️'],
        'hearts' => ['❤️', '❤️', '❤️', '❤️', '❤️'],
    ];
    public static $aliases   = ['rating'];

    use GenerateInputName;

    public static function render(Block $block)
    {
        $list = Html::create(
            'div',
            [
                'class' => [
                    'totalsurvey-rating',
                    "is-{$block->option('symbol')}",
                ],
            ]
        );

        $symbols = static::$symbols[$block->option('symbol')];

        $items = [];
        foreach ($symbols as $value => $icon) {
            $id = "{$block->uid}-{$value}";

            $item  = Html::create(
                'label',
                ['class' => 'totalsurvey-rating-item', 'for' => $id],
                Html::create('span', [], $icon)
            );
            $input = Html::create(
                'input',
                [
                    'type'                => 'radio',
                    'name'                => static::getInputName($block->section->uid, $block->uid),
                    'id'                  => $id,
                    'class'               => $block->option('cssClass'),
                    'placeholder'         => $block->option('placeholder'),
                    'value'               => $value + 1,
                    'data-variable-name'    => $block->uid,
                    'data-variable-value' => static::getSymbolLabel($block->option('symbol'), $value + 1),
                ]
            );

            $items[] = $item;
            $items[] = $input;
        }

        $list->addContent(array_reverse($items));

        return $list;
    }

    public static function getEntryBlockFromRawValue($value, Block $block, EntrySection $entrySection, Entry $entry)
    {
        $entryBlock = parent::getEntryBlockFromRawValue($value, $block, $entrySection, $entry);

        $symbol            = $block->option('symbol', 'stars');
        $entryBlock->value = (int) $value;
        $entryBlock->text  = static::getSymbolLabel($symbol, $value);

        $entryBlock->meta->set('value', static::getSymbolValue($symbol, $value));
        $entryBlock->meta->set('symbol', $symbol);

        return $entryBlock;
    }

    public static function getSymbolValue($symbol, $value)
    {
        if ($symbol === 'faces') {
            return Arrays::get(static::$symbols[$symbol], $value - 1, '');
        }

        return implode(' ', array_slice(static::$symbols[$symbol], 0, $value));
    }

    public static function getSymbolLabel($symbol, $value)
    {
        $labels = [
            'faces'  => [
                __('Very Sad', 'totalsurvey'),
                __('Sad', 'totalsurvey'),
                __('Neutral', 'totalsurvey'),
                __('Happy', 'totalsurvey'),
                __('Very Happy', 'totalsurvey'),
            ],
            'hearts' => _n('%d heart', '%d hearts', $value, 'totalsurvey'),
            'stars'  => _n('%d star', '%d stars', $value, 'totalsurvey'),
        ];

        if ($symbol === 'faces') {
            return $labels[$symbol][$value - 1] ?? '';
        }

        return sprintf($labels[$symbol], $value);
    }

    public static function getSymbolAltValue($value)
    {
        return str_repeat('★', $value).str_repeat('☆', 5 - $value);
    }
}
