<?php

namespace TotalSurvey\Extensions\Insights\Actions;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Capabilities\UserCanExportData;
use TotalSurvey\Extensions\Insights\Tasks\ExportCsv;
use TotalSurvey\Extensions\Insights\Tasks\ExportJson;
use TotalSurvey\Extensions\Insights\Tasks\GenerateInsightsForSurvey;
use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Action;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\NotFoundException;
use TotalSurveyVendors\TotalSuite\Foundation\Http\Response;

class Export extends Action
{
    /**
     * @param  string  $surveyUid
     *
     * @param $format
     *
     * @return Response
     * @throws Exception
     */
    public function execute($surveyUid, $format)
    {
        $survey = Survey::byUid($surveyUid);

        $data = GenerateInsightsForSurvey::invoke(
            $survey,
            $this->request->getParam('fromDate'),
            $this->request->getParam('toDate'),
            wp_validate_boolean($this->request->getParam('includeObsolete'))
        );

        if ($format === 'json') {
            return ExportJson::invoke($data);
        }

        if ($format === 'csv') {
            return ExportCsv::invoke($data);
        }

        throw new NotFoundException();
    }

    public function authorize(): bool
    {
        return UserCanExportData::check();
    }

    /**
     * @return array
     */
    public function getParams(): array
    {
        return [
            'surveyUid' => [
                'expression'        => '(?<surveyUid>([\w-]+))',
                'sanitize_callback' => static function ($surveyUid) {
                    return (string) $surveyUid;
                },
            ],
            'format'    => [
                'expression'        => '(?<format>([\w]+))',
                'sanitize_callback' => function ($format) {
                    return (string) $format;
                },
            ],
        ];
    }
}
