<?php

namespace TotalSurvey\Extensions\Insights\Actions;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Capabilities\UserCanViewData;
use TotalSurvey\Extensions\Insights\Tasks\GenerateInsightsForSurvey;
use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Action;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\Http\Response;
use TotalSurveyVendors\TotalSuite\Foundation\Http\ResponseFactory;

class Index extends Action
{
    /**
     * @param  string  $surveyUid
     *
     * @return Response
     * @throws Exception
     */
    public function execute($surveyUid)
    {
        $survey = Survey::byUid($surveyUid);

        $data = GenerateInsightsForSurvey::invoke(
            $survey,
            $this->request->getParam('fromDate'),
            $this->request->getParam('toDate'),
            wp_validate_boolean($this->request->getParam('includeObsolete'))
        );

        return ResponseFactory::json($data);
    }

    public function authorize(): bool
    {
        return UserCanViewData::check();
    }

    /**
     * @return array
     */
    public function getParams(): array
    {
        return [
            'surveyUid' => [
                'expression'        => '(?<surveyUid>([\w-]+))',
                'sanitize_callback' => static function ($surveyUid) {
                    return (string) $surveyUid;
                },
            ],
        ];
    }
}
