<?php

namespace TotalSurvey\Extensions\Insights\Tasks;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Extensions\Insights\Models\Insights;
use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\DatabaseException;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\Task;

/**
 * Class CreateInsights
 *
 * @package TotalSurvey\Extensions\Insights\Tasks
 * @method static Insights invoke(Survey $survey, $from = null, $to = null, $includeObsolete = false)
 * @method static Insights invokeWithFallback($fallback, Survey $survey, $from = null, $to = null, $includeObsolete = false)
 */
class CreateInsights extends Task
{
    /**
     * @var Survey
     */
    protected $survey;

    /**
     * @var string
     */
    protected $to;

    /**
     * @var mixed|null
     */
    protected $from;

    /**
     * @var bool
     */
    protected $includeObsolete;

    /**
     * @var array
     */
    protected $expirationCache;


    /**
     * Create constructor.
     *
     * @param  Survey  $survey
     * @param    $from
     * @param    $to
     */

    public function __construct(Survey $survey, $from = null, $to = null, $includeObsolete = false)
    {
        $this->survey          = $survey;
        $this->from            = $from;
        $this->to              = $to;
        $this->includeObsolete = $includeObsolete;
        $this->expirationCache = ['number_entries' => 100, 'seconds' => 10];
    }

    /**
     * @return bool
     * @throws Exception
     */
    public function validate()
    {
        return true;
    }

    /**
     * @return false|mixed|Insights
     * @throws Exception
     * @throws DatabaseException
     * @throws \Exception
     */
    public function execute()
    {
        $uid      = $this->survey->uid;
        $cacheKey = md5("survey-$uid-from-$this->from-to-$this->to-include-obsolete-$this->includeObsolete");
        if ($cachedData = get_transient($cacheKey)):
            return new Insights(['data' => $cachedData, 'survey' => $this->survey]);
        endif;

        $data     = GenerateInsightsForSurvey::invoke(
            $this->survey,
            $this->from,
            $this->to,
            wp_validate_boolean($this->includeObsolete)
        );
        set_transient($cacheKey, $data, $this->getExpirationTime($data['count']['total']));

        return new Insights(['data' => $data, 'survey' => $this->survey]);
    }

    private function getExpirationTime(int $total): int
    {
        $expiration = (int) ($total * $this->expirationCache['seconds'] / $this->expirationCache['number_entries']);

        return max($expiration, 10);
    }
}
