<?php

namespace TotalSurvey\Extensions\Insights\Tasks;
! defined( 'ABSPATH' ) && exit();



use Exception;
use TotalSurvey\Extensions\Insights\Models\Insights;
use TotalSurveyVendors\TotalSuite\Foundation\Contracts\Support\HTMLRenderable;
use TotalSurveyVendors\TotalSuite\Foundation\Helpers\Html;
use TotalSurveyVendors\TotalSuite\Foundation\Task;

/**
 * Class DisplayInsights
 *
 * @package TotalSurvey\Extensions\Insights\Tasks
 * @method static string invoke(Insights $insights)
 * @method static string invokeWithFallback($fallback, Insights $insights)
 */
class DisplayInsights extends Task
{

    /**
     * @var Insights
     */
    protected $insights;

    /**
     * @var bool
     */
    protected $embed;

    public function __construct(Insights $insights, $embed = false)
    {
        $this->insights = $insights;
        $this->embed    = $embed;
    }

    /**
     * @return bool
     */
    protected function validate()
    {
        return true;
    }

    /**
     * @return mixed
     * @throws Exception
     */
    protected function execute()
    {
        try {

            return $this->insights->render($this->embed);
        } catch (Exception $exception) {
            if ($exception instanceof HTMLRenderable) {
                $html = $exception->toHTML();
            } else {
                $html = Html::create('p', [], $exception->getMessage());
            }

            return $html;
        }
    }
}
