<?php

namespace TotalSurvey\Extensions\Insights\Tasks;
! defined( 'ABSPATH' ) && exit();



use TotalSurveyVendors\TotalSuite\Foundation\Http\Message;
use TotalSurveyVendors\TotalSuite\Foundation\Http\Response;
use TotalSurveyVendors\TotalSuite\Foundation\Http\ResponseFactory;
use TotalSurveyVendors\TotalSuite\Foundation\Task;

/**
 * Class ExportCsv
 *
 * @method static Response invoke(array $entries)
 * @method static Response invokeWithFallback($fallback, array $entries)
 */
class ExportCsv extends Task
{
    protected $data;

    /**
     * constructor.
     *
     * @param  array  $data
     */
    public function __construct(array $data)
    {
        $this->data = $data;
    }

    /**
     * @inheritDoc
     */
    protected function validate()
    {
        return true;
    }

    /**
     * @return Message
     */
    protected function execute()
    {
        $content = [];

        foreach ($this->data['sections'] as $section) {
            foreach ($section['blocks'] as $question) {
                $section['headers'] = [];
                $section['data']    = [];

                $section['headers'] = [
                    __('Section', 'totalsurvey'),
                ];

                $section['data'] = [
                    esc_html($section['title']),
                ];

                $section['headers'][] = __('Question', 'totalsurvey');
                $section['data'][]    = esc_html(strip_tags($question['title']));

                if ($question['type'] === 'matrix') {
                    foreach ($question['values']['criteria'] as $label => $value) {
                        $section['headers'][] = $label;

                        $data = [];

                        foreach ($value['values'] as $k => $v) {
                            $data[] = sprintf('%s (%s)', esc_html($k), (int) $v);
                        }

                        $section['data'][] = esc_html(implode(', ', $data));
                    }
                } else {
                    foreach ($question['values'] as $label => $value) {
                        $section['headers'][] = $label;
                        $section['data'][]    = esc_html($value);
                    }
                }

                $section['headers'][] = __('Total', 'totalsurvey');
                $section['data'][]    = esc_html($question['total']);

                $content[] = implode(';', $section['headers']);
                $content[] = implode(';', $section['data']);
                $content[] = '';
            }
        }

        $csv = sprintf("sep=;%s", PHP_EOL);
        $csv .= implode(PHP_EOL, $content);

        $filename = sprintf("entries-export-%s.csv", date('Y-m-d'));

        return ResponseFactory::file($csv, $filename, 'text/csv')
                              ->withAddedHeader('Content-Encoding', 'UTF-8');
    }
}
