<?php

namespace TotalSurvey\Extensions\Insights\Tasks;
! defined( 'ABSPATH' ) && exit();



use Exception;
use TotalSurvey\Extensions\Insights\Models\Insights;
use TotalSurvey\Plugin;
use TotalSurvey\Views\Template;
use TotalSurveyVendors\TotalSuite\Foundation\Contracts\Support\HTMLRenderable;
use TotalSurveyVendors\TotalSuite\Foundation\Helpers\Html;
use TotalSurveyVendors\TotalSuite\Foundation\Task;

/**
 * Class RenderSurvey
 *
 * @package TotalSurvey\Extensions\Insights\Tasks
 */
class RenderInsights extends Task
{
    /**
     * @var Insights
     */
    protected $insights;
    /**
     * @var Template
     */
    protected $template;

    /**
     * @var bool
     */
    protected $embed;


    /**
     * RenderInsights constructor.
     *
     * @param  Template  $template
     * @param  Insights  $insights
     */
    public function __construct(Template $template, Insights $insights, $embed = false)
    {
        $this->insights = $insights;
        $this->template = $template;
        $this->embed    = $embed;
    }

    /**
     * @inheritDoc
     */
    protected function validate()
    {
        return true;
    }

    /**
     * @inheritDoc
     * @throws Exception
     */
    protected function execute()
    {
        try {
            $rendered = $this->template->renderInsights(
                $this->insights->survey,
                array_values(
                    array_filter($this->insights->data['sections'], function ($section) {
                        return count($section['blocks']) > 0;
                    })
                ) ?? [],
                $this->embed
            );
        } catch (Exception $exception) {
            if ($exception instanceof HTMLRenderable) {
                $rendered = $exception->toHTML();
            } else {
                $rendered = Html::create('p', [], $exception->getMessage());
            }
        }

        $wrapper = Html::create(
            'div',
            [
                'id'    => "totalsurvey-insights-{$this->insights->survey->uid}",
                'class' => 'totalsurvey-insights-wrapper',
            ],
            $rendered
        );

        if (Plugin::options('general.showCredits', false)) {
            $credit = Html::create(
                'div',
                [
                    'class' => 'totalsurvey-credits',
                    'style' => 'font-family: sans-serif; font-size: 9px; text-transform: uppercase;text-align: center; padding: 10px 0;',
                ],
                sprintf(
                    __('Powered by %s', 'totalsurvey'),
                    Html::create('a', ['href' => 'https://totalsuite.net/products/totalsurvey'], 'totalsurvey')
                )
            );

            return $wrapper->addContent($credit);
        }

        return $wrapper->render();
    }
}
