<?php


namespace TotalSurvey\Extensions\Insights\Tasks;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\UnauthorizedException;
use TotalSurveyVendors\TotalSuite\Foundation\Task;
use TotalSurveyVendors\TotalSuite\Foundation\View\Engine;
use TotalSurveyVendors\TotalSuite\Foundation\WordPress\Modules\Manager;

class SetupViewInsightsTemplate extends Task
{
    protected function validate()
    {
        return true;
    }

    protected function execute()
    {
        add_filter(
            'query_vars',
            static function ($queryVars) {
                $queryVars[] = 'survey_insights_uid';
                $queryVars[] = 'from';
                $queryVars[] = 'to';
                $queryVars[] = 'include_obsolete';

                return $queryVars;
            }
        );

        add_action(
            'init',
            static function () {
                add_rewrite_rule(
                    "survey-insights/([a-z0-9-]+)[/]?$",
                    'index.php?survey_insights_uid=$matches[1]',
                    'top'
                );
            }
        );

        add_action('template_redirect', [$this, 'handleTemplateRedirect']);
    }

    public function handleTemplateRedirect()
    {
        if ($surveyUid = get_query_var('survey_insights_uid')) {
            try {
                $embed           = filter_input(INPUT_GET, 'embed');
                $publishToken    = filter_input(INPUT_GET, 'publish_token');
                $from            = filter_input(INPUT_GET, 'from') ?: null;
                $to              = filter_input(INPUT_GET, 'to') ?: null;
                $includeObsolete = wp_validate_boolean(filter_input(INPUT_GET, 'include_obsolete'));
                $survey          = Survey::byUidAndActive($surveyUid);

                if (!$survey->isValidInsightsPublishToken($publishToken)) {
                    UnauthorizedException::throw('You are not allowed to access this page.');
                }

                $insights = CreateInsights::invoke($survey, $from, $to, $includeObsolete);

                echo ViewInsights::invoke(
                    Manager::instance(),
                    Engine::instance(),
                    $insights,
                    filter_var($embed, FILTER_VALIDATE_BOOLEAN)
                );
            } catch (\Exception $exception) {
                wp_die($exception->getMessage(), get_bloginfo('name'));
            }
            exit;
        }
    }
}
