<?php

namespace TotalSurvey\Extensions\Insights\Tasks;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Extensions\Insights\Models\Insights;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\Task;
use TotalSurveyVendors\TotalSuite\Foundation\View\Engine;
use TotalSurveyVendors\TotalSuite\Foundation\WordPress\Modules\Manager;

/**
 * Class ViewInsights
 *
 * @package TotalSurvey\Extensions\Insights\Tasks
 */
class ViewInsights extends Task
{
    /**
     * @var Insights
     */
    protected $insights;

    /**
     * @var Engine
     */
    protected $engine;

    /**
     * @var Manager
     */
    protected $manager;

    /**
     * @var Insights
     */
    protected $embed;


    /**
     * ViewSuvey constructor.
     *
     * @param  Manager  $manager
     * @param  Engine  $engine
     * @param  Insights  $insights
     * @param  bool  $embed
     */
    public function __construct(Manager $manager, Engine $engine, Insights $insights, $embed = false)
    {
        $this->insights = $insights;
        $this->manager  = $manager;
        $this->engine   = $engine;
        $this->embed    = $embed;
    }

    /**
     * @inheritDoc
     */
    protected function validate()
    {
        return true;
    }

    /**
     * @inheritDoc
     * @throws Exception
     * @throws \Exception
     */
    protected function execute()
    {
        $renderedInsights = DisplayInsights::invoke($this->insights, $this->embed);

        // Add survey to the title
        add_filter(
            'wp_title_parts',
            function ($parts) {
                return [
                    $this->insights->survey->name ?: esc_html__('Untitled survey', 'totalsurvey'),
                    esc_html__('Insights', 'totalsurvey'),
                    get_bloginfo('name'),
                ];
            }
        );

        // Add description meta tag
        add_action(
            'wp_head',
            function () {
                if ($this->embed) {
                    show_admin_bar(false);
                }
                printf('<meta name="description" content="%s">'.PHP_EOL, $this->insights->survey->description);
            },
            1
        );

        // Render insights view

        return $this->engine->render(
            'insights',
            [
                'insights' => $this->insights,
                'content'  => $renderedInsights,
                'embed'    => $this->embed,
            ]
        );
    }
}
