<?php

namespace TotalSurvey\Extensions\Limitations;
! defined( 'ABSPATH' ) && exit();



use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Support\Arrays;

class LimitationDefinition
{
    /**
     * @var bool
     */
    protected $enabled = false;

    /**
     * @var int
     */
    protected $submissions = 1;

    /**
     * @var int
     */
    protected $timeout = 1;

    /**
     * @var array
     */
    protected $options = [];

    /**
     * Definition constructor.
     *
     * @param  bool  $enabled
     * @param  int  $submissions
     * @param  int  $timeout
     * @param  array  $options
     */
    public function __construct(bool $enabled,
        int $submissions,
        int $timeout,
        array $options = [])
    {
        $this->enabled = $enabled;
        $this->submissions = $submissions;
        $this->timeout = $timeout;
        $this->options = $options;
    }

    /**
     * @return bool
     */
    public function isEnabled()
    {
        return $this->enabled;
    }

    /**
     * @return int
     */
    public function getSubmissions()
    {
        return $this->submissions;
    }

    /**
     * @return int
     */
    public function getTimeout()
    {
        return (int)$this->timeout;
    }

    /**
     * @param  string  $name
     * @param  mixed  $value
     */
    public function setOption($name, $value)
    {
        Arrays::set($this->options, $name, $value);
    }

    /**
     * @param  string  $name
     * @param  null  $default
     *
     * @return mixed|null
     */
    public function getOption($name, $default = null)
    {
        return Arrays::get($this->options, $name, $default);
    }

    /**
     * @return array
     */
    public function getOptions()
    {
        return $this->options;
    }

    /**
     * @param  array  $options
     */
    public function setOptions(array $options)
    {
        $this->options = $options;
    }

    public static function get(Survey $survey, $type)
    {
        $limitation = $survey->getLimitationParams('entry', $type);

        return new static(Arrays::get($limitation, 'enabled', false),
            Arrays::get($limitation, 'submissions', 1),
            Arrays::get($limitation, 'timeout', 1),
            Arrays::get($limitation, 'options', []));
    }


}
