<?php

namespace TotalSurvey\Extensions\Limitations\Strategies;
! defined( 'ABSPATH' ) && exit();



use TotalSurvey\Extensions\Limitations\LimitationDefinition;
use TotalSurvey\Extensions\Limitations\LimitationStrategy;
use TotalSurvey\Models\Entry;
use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\Http\Response;

class CookieLimitationStrategy extends LimitationStrategy
{
    /**
     * @var int
     */
    protected $currentValue = 0;


    /**
     * @param  Survey  $survey
     * @param  bool  $next
     *
     * @return mixed
     * @throws Exception
     */
    public function check(Survey $survey, $next = false)
    {
        $limitation = LimitationDefinition::get($survey, 'cookie');

        if (!$limitation->isEnabled()) {
            return $survey;
        }

        $cookie = $this->getCookieData($limitation);

        $check = false;

        if($cookie) {
            if($next) {
                $check = ($cookie['submissions'] + 1) >= $limitation->getSubmissions();
            } else {
                $check =  $cookie['submissions'] >= $limitation->getSubmissions();
            }
        } elseif ($next) {
            $check = 1 >= $limitation->getSubmissions();
        }

        Exception::throwIf($check, __('Submissions quota exceeded', 'totalsurvey'));

        return true;
    }

    /**
     * @param  Response  $response
     * @param  Survey  $survey
     * @param  Entry  $entry
     *
     * @return Response
     */
    public function apply(Response $response, Survey $survey, Entry $entry)
    {
        $limitation = LimitationDefinition::get($survey, 'cookie');

        if (!$limitation->isEnabled()) {
            return $response;
        }

        $cookie = $this->getCookieData($limitation);

        if(!$cookie) {
            $cookie = [
                'submissions' => 1,
                'date' => $limitation->getTimeout() === 0 ? 0 : time() + ($limitation->getTimeout() * 60 )
            ];
        } else {
            $cookie['submissions'] += 1;
        }

        return $response->withCookie("ts_limitation_{$limitation->getOption('uid')}", json_encode($cookie), $cookie['date']);
    }

    /**
     * @param  Survey  $survey
     *
     * @return bool|mixed
     */
    public function reset(Survey $survey)
    {
        $survey->setAttribute('settings.limitations.entry.cookie.options.uid', wp_generate_uuid4());

        return true;
    }


    /**
     * @param  LimitationDefinition  $limitation
     *
     * @return array|mixed
     */
    protected function getCookieData(LimitationDefinition $limitation)
    {
        $cookie = $this->request->getCookieParam("ts_limitation_{$limitation->getOption('uid')}", false);

        if (!$cookie) {
            return false;
        } else {
            $cookie = json_decode($cookie, true);
        }

        return $cookie;
    }
}
