<?php

namespace TotalSurvey\Extensions\Limitations\Strategies;
! defined( 'ABSPATH' ) && exit();



use TotalSurvey\Extensions\Limitations\LimitationDefinition;
use TotalSurvey\Extensions\Limitations\LimitationStrategy;
use TotalSurvey\Models\Entry;
use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Database\Query\Expression;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\Http\Response;

class UserLimitationStrategy extends LimitationStrategy
{
    /**
     * @param  Survey  $survey
     * @param  bool  $next
     *
     * @return mixed
     * @throws Exception
     */
    public function check(Survey $survey, $next = false)
    {
        $limitation = LimitationDefinition::get($survey, 'user');

        if (!$limitation->isEnabled() || !is_user_logged_in()) {
            return $survey;
        }

        $query = Entry::query()
                      ->where('user_id', get_current_user_id())
                      ->where('survey_uid', $survey->uid);

        if ($limitation->getTimeout() > 0) {
            $exp = new Expression("NOW() - INTERVAL {$limitation->getTimeout()} MINUTE");
            $query->where('created_at', '>=', $exp);
        }

        Exception::throwIf(
            $query->count() >= $limitation->getSubmissions(),
            __('Submissions quota exceeded', 'totalsurvey')
        );

        return true;
    }

    /**
     * @param  Response  $response
     * @param  Survey  $survey
     * @param  Entry  $entry
     *
     * @return Response
     */
    public function apply(Response $response, Survey $survey, Entry $entry)
    {
        return $response;
    }
}
