<?php

namespace TotalSurvey\Extensions\Popup;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Capabilities\UserCanManageOptions;
use TotalSurvey\Events\OnBackofficeAssetsEnqueued;
use TotalSurvey\Events\OnRoutesRegistered;
use TotalSurvey\Extensions\Popup\Actions\Get;
use TotalSurvey\Extensions\Popup\Actions\Save;
use TotalSurvey\Extensions\Popup\Model\Popup;
use TotalSurvey\Extensions\Popup\Tasks\DisplayPopup;
use TotalSurvey\Extensions\Popup\Tasks\GetDefaults;
use TotalSurvey\Extensions\Popup\Tasks\GetPopup;
use TotalSurvey\Plugin;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\View\Engine;
use TotalSurveyVendors\TotalSuite\Foundation\WordPress\Modules\Extension;
use TotalSurveyVendors\TotalSuite\Foundation\WordPress\Options;

class Module extends Extension
{
    const STORAGE_KEY = 'totalsurvey_popup';
    /**
     * @var Popup
     */
    protected $popup;

    public function run()
    {
        // Routes
        OnRoutesRegistered::listen([$this, 'registerRoutes']);

        // Shortcode
        new Shortcodes\Popup();

        // Display
        add_action('wp_footer', [$this, 'displayPopupForContext']);
        add_action('totalsurvey/display/popup', [$this, 'displayPopupFromCode']);

        // Filter
        Filters\PopupFilter::add([$this, 'bootstrap'], 99, 2);
    }

    /**
     * Get popup settings.
     *
     * @return Popup
     * @throws Exception
     */
    public function getPopup()
    {
        if (!$this->popup instanceof Popup) {
            $options = $this->container->get(Options::class)
                                       ->withKey(self::STORAGE_KEY, GetDefaults::invoke());

            $this->popup = GetPopup::invoke($options);
        }

        return $this->popup;
    }

    /**
     * @param  null  $target
     *
     * @param  bool  $viaCode
     *
     * @return mixed|string
     * @throws Exception
     */
    public function bootstrap($target = null, $viaCode = false)
    {
        $popup = $this->getPopup();

        if (!$popup->enabled) {
            return '';
        }

        if ($popup->target === 'code' && !$viaCode) {
            return '';
        }

        if (!empty($target)) {
            $popup->target = $target;
        }

        doing_action('wp_footer') ? $this->frontendAssets() : add_action('wp_footer', [$this, 'frontendAssets']);

        /**
         * @var Engine $view
         */
        $view = new Engine($this->getPath('views'));
        $popup->style = Plugin::env()->isDebug() ? $this->getUrl('assets/style.css') : $this->getUrl(
            'assets/style.min.css'
        );

        return DisplayPopup::invoke($view, $popup);
    }

    /**
     * Display for current context
     */
    public function displayPopupForContext()
    {
        echo Filters\PopupFilter::apply(null);
    }

    public function displayPopupFromCode()
    {
        echo Filters\PopupFilter::apply('code', true);
    }

    /**
     * @param  OnRoutesRegistered  $event
     */
    public function registerRoutes(OnRoutesRegistered $event)
    {
        $event->getRouter()
              ->post('/admin/popup', Save::class)
              ->capability(UserCanManageOptions::class);
        $event->getRouter()
              ->get('/admin/popup', Get::class)
              ->capability(UserCanManageOptions::class);
    }

    /**
     * Frontend
     */
    public function frontendAssets()
    {
        wp_enqueue_script(
            'totalsurvey-popup-script',
            $this->getUrl(
                Plugin::env()
                      ->isDebug() ? 'assets/main.js' : 'assets/main.min.js'
            ),
            [],
            null,
            true
        );
    }

}
