<?php


namespace TotalSurvey\Extensions\Popup\Tasks;
! defined( 'ABSPATH' ) && exit();



use Throwable;
use TotalSurvey\Extensions\Popup\Model\Popup;
use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Task;
use TotalSurveyVendors\TotalSuite\Foundation\View\Engine;

/**
 * Class RenderPopup
 *
 * @package TotalSurvey\Extensions\Popup\Tasks
 */
class RenderPopup extends Task
{
    /**
     * @var Engine
     */
    protected $view;

    /**
     * @var Survey
     */
    protected $survey;

    /**
     * @var Popup
     */
    protected $popup;


    /**
     * RenderPopup constructor.
     *
     * @param  Engine  $view
     * @param  Survey  $survey
     * @param  Popup  $popup
     */
    public function __construct(Engine $view, Survey $survey, Popup $popup)
    {
        $this->view   = $view;
        $this->survey = $survey;
        $this->popup  = $popup;
    }


    /**
     * @return bool|mixed|void
     */
    protected function validate()
    {
        return true;
    }

    /**
     * @return mixed|void
     */
    protected function execute()
    {
        try {
            $html = $this->survey->render();

            return $this->view->render(
                'index',
                [
                    'survey' => $html,
                    'popup'  => $this->popup,
                ]
            );
        } catch (Throwable $e) {
            return '';
        }
    }
}
