"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var PopupExtension;
(function (PopupExtension) {
    var PROMPT_SELECTOR = '.prompt';
    var POPUP_SELECTOR = '.popup';
    var OPEN_BUTTON_SELECTOR = '.prompt-open';
    var SURVEY_SELECTOR = '.totalsurvey-survey';
    var CLOSE_SELECTOR = '.close-popup';
    var MESSAGE_SELECTOR = '.message';
    var SHOW_CLASS_TOKEN = '-show';
    var OPEN_CLASS_TOKEN = '-open';
    var CLOSED_TOKEN = 'closed';
    var PREFIX = 'totalsurvey-popup';
    var Popup = /** @class */ (function () {
        function Popup(popup) {
            var _this = this;
            this.popup = popup;
            this.options = {
                delay: 0,
                close: 0,
                survey: null,
                messages: null
            };
            // Parse and fill settings
            var userOptions = JSON.parse(this.popup.dataset.options || '{}');
            Object.assign(this.options, userOptions);
            popup.removeAttribute('data-options');
            // Bail if already closed
            if (this.closed) {
                popup.remove();
                return;
            }
            // Listen to close
            this.popup.shadowRoot.querySelectorAll(CLOSE_SELECTOR).forEach(function (button) {
                button.addEventListener('click', _this.remove.bind(_this), false);
            });
            this.openButton.addEventListener('click', this.open.bind(this), false);
            // Open
            setTimeout(this.show.bind(this), this.options.delay * 1000);
            // Submit
            // @ts-ignore
            this.survey.instance.$on('submit', this.handleSubmit.bind(this));
        }
        Popup.prototype.handleSubmit = function () {
            var _a;
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_b) {
                    (_a = this.survey.host.parentElement) === null || _a === void 0 ? void 0 : _a.remove();
                    this.message.classList.add('-show');
                    this.closed = true;
                    if (this.message.innerText == '') {
                        this.remove();
                    }
                    else if (this.options.close > 0) {
                        setTimeout(this.remove.bind(this), this.options.close * 1000);
                    }
                    return [2 /*return*/];
                });
            });
        };
        Object.defineProperty(Popup.prototype, "message", {
            get: function () {
                return this.popup.shadowRoot.querySelector(MESSAGE_SELECTOR);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Popup.prototype, "survey", {
            get: function () {
                return this.popup.shadowRoot.querySelector(SURVEY_SELECTOR).shadowRoot;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Popup.prototype, "openButton", {
            get: function () {
                return this.popup.shadowRoot.querySelector(OPEN_BUTTON_SELECTOR);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Popup.prototype, "closed", {
            get: function () {
                return localStorage.getItem(this.popupId) === CLOSED_TOKEN;
            },
            set: function (value) {
                if (value) {
                    window.localStorage.setItem(this.popupId, CLOSED_TOKEN);
                }
                else {
                    window.localStorage.removeItem(this.popupId);
                }
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Popup.prototype, "popupId", {
            get: function () {
                return PREFIX + "-" + this.options.survey;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Popup.prototype, "prompt", {
            get: function () {
                return this.popup.shadowRoot.querySelector(PROMPT_SELECTOR);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Popup.prototype, "container", {
            get: function () {
                return this.popup.shadowRoot.querySelector(POPUP_SELECTOR);
            },
            enumerable: false,
            configurable: true
        });
        Popup.prototype.remove = function () {
            this.closed = true;
            this.popup.remove();
            document.documentElement.style.overflowY = 'initial';
        };
        Popup.prototype.show = function () {
            return this.container.classList.add('-show');
        };
        Popup.prototype.open = function () {
            var _this = this;
            document.documentElement.style.overflowY = 'hidden';
            this.container.classList.remove(SHOW_CLASS_TOKEN);
            this.container.classList.add(OPEN_CLASS_TOKEN);
            setTimeout(function () {
                _this.prompt.remove();
            }, 500);
        };
        return Popup;
    }());
    PopupExtension.Popup = Popup;
    // Bootstrap
    window.addEventListener('DOMContentLoaded', function () {
        var popup = document.getElementById('totalsurvey-popup');
        if (popup) {
            var template = popup.querySelector('template#totalsurvey-popup-template');
            var content = popup.querySelector('#totalsurvey-popup-content');
            var loader = popup.querySelector('#totalsurvey-popup-loader');
            popup.attachShadow({ mode: 'open' }).append(template.content);
            popup.shadowRoot.querySelector('.content').append(content.firstChild);
            popup.shadowRoot.querySelector('.prompt').prepend(loader.firstChild);
            content.remove();
            loader.remove();
            template.remove();
            new Popup(popup);
        }
    }, false);
})(PopupExtension || (PopupExtension = {}));
//# sourceMappingURL=main.js.map
