<?php
! defined( 'ABSPATH' ) && exit();

/**
 * @var string $survey
 * @var Popup $popup
 */

use TotalSurvey\Extensions\Popup\Model\Popup;
use TotalSurveyVendors\TotalSuite\Foundation\Helpers\Colors;

?>

<div id="totalsurvey-popup" data-options="<?php
echo esc_attr(json_encode($popup->getAttributes())) ?>">

    <div hidden id="totalsurvey-popup-survey">
        <?php
        echo wp_kses($survey, \TotalSurvey\Tasks\Utils\GetAllowedSurveyTags::invoke()) ?>
    </div>

    <template id="totalsurvey-popup-template">
        <style media="screen">
            @import url('<?php echo esc_url($popup->style); ?>');

            * {
                box-sizing: border-box;
            }

            :host {
                --font-size-large: 18px;
                --font-size: 16px;
                --font-size-small: 14px;

                --color-primary: <?php echo esc_html($popup->getAttribute('colors.primary')); ?>;
                --color-primary-dark: <?php echo esc_html(Colors::darken($popup->getAttribute('colors.primary'), 20)); ?>;
                --color-primary-light: <?php echo esc_html(Colors::lignten($popup->getAttribute('colors.primary'), 20)); ?>;
                --color-primary-alpha: <?php echo esc_html(Colors::opacity($popup->getAttribute('colors.primary'), 0.25)); ?>;

                --color-forground: <?php echo esc_html($popup->getAttribute('colors.foreground')); ?>;
                --color-forground-dark: <?php echo esc_html(Colors::darken($popup->getAttribute('colors.background'), 88)); ?>;
                --color-forground-light: <?php echo esc_html(Colors::lignten($popup->getAttribute('colors.background'), 10)); ?>;

                --color-background: <?php echo esc_html($popup->getAttribute('colors.background')); ?>;
                --color-background-dark: <?php echo esc_html(Colors::darken($popup->getAttribute('colors.background'), 20)); ?>;
                --color-background-light: <?php echo esc_html(Colors::lignten($popup->getAttribute('colors.background'), 20)); ?>;

                --border-radius: <?php echo esc_html($popup->getAttribute('radius')); ?>px;
            }

        </style>

        <div hidden class="popup">
            <?php
            if ($popup->shouldSkipPrompt()): ?>
                <div class="prompt <?php
                echo esc_attr("position-{$popup->getPosition()} shadow-{$popup->getShadow()}"); ?>">
                    <button class="button button-close close-popup"></button>

                    <div class="popup-survey"></div>
                    <div hidden class="popup-thankyou">
                        <?php
                        echo nl2br(esc_html($popup->getThankYouMessage())) ?>
                    </div>
                </div>
            <?php
            else: ?>
                <div hidden class="popup-overlay">
                    <div class="popup-overlay-content">
                        <button class="button button-close close-popup"></button>

                        <div class="popup-survey"></div>
                        <div hidden class="popup-thankyou">
                            <?php
                            echo nl2br(esc_html($popup->getThankYouMessage())) ?>
                        </div>
                    </div>
                </div>

                <div class="prompt <?php
                echo esc_attr("position-{$popup->getPosition()} shadow-{$popup->getShadow()}"); ?>">
                    <div class="prompt-content"><?php
                        echo do_shortcode(nl2br(esc_html($popup->getPromptMessage())), true); ?></div>
                    <div class="buttons">
                        <button class="button is-primary prompt-open"><?php
                            echo esc_html($popup->getStartButtonLabel()); ?></button>
                        <button class="button is-secondary prompt-discard close-popup"><?php
                            echo esc_html($popup->getDiscardButtonLabel()); ?></button>
                    </div>
                    <button class="button button-close close-popup"></button>
                </div>
            <?php
            endif; ?>
        </div>
    </template>
</div>
