<?php

namespace TotalSurvey\Extensions\Scoring\Model;
! defined( 'ABSPATH' ) && exit();


use TotalSurveyVendors\TotalSuite\Foundation\Database\Model;
use TotalSurveyVendors\TotalSuite\Foundation\Support\Collection;
use TotalSurveyVendors\TotalSuite\Foundation\Support\Strings;

/**
 * @property Collection|ScoringSection[] sections
 * @property int score
 * @property Collection|ScoringGrade[] grades
 */
class Scoring extends Model
{
    /**
     * @var string[]
     */
    protected $types = [
        'sections' => 'sections',
        'grades'   => 'grades',
        'score'    => 'int',
    ];

    /**
     * @param  array  $data
     *
     * @return Collection
     */
    public function castToSections($data)
    {
        $sections = [];

        foreach ($data as $section) {
            $sections[] = new ScoringSection($section);
        }

        return Collection::create($sections);
    }

    /**
     * @param  array  $data
     *
     * @return Collection
     */
    public function castToGrades($data)
    {
        $grades = [];


        foreach ($data as $grade) {
            $grades[] = new ScoringGrade($this, $grade);
        }

        return Collection::create($grades);
    }

    /**
     * @param $percentage
     *
     * @return ScoringGrade
     */
    public function getEntryGrade($percentage)
    {
        foreach ($this->grades as $grade) {
            if ($grade->check($percentage)) {
                return $grade;
            }
        }

        // Fallback

        return new ScoringGrade(
            $this,
            [
                'uid'     => '',
                'label'   => __('Done', 'totalsurvey'),
                'color'   => '#888',
                'content' => '',
            ]
        );
    }
}
