<?php

namespace TotalSurvey\Extensions\Scoring\Model;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Models\Block;
use TotalSurvey\Models\Concerns\HasRichText;
use TotalSurvey\Models\Concerns\Translatable;
use TotalSurvey\Models\Section;
use TotalSurvey\Models\Survey;
use TotalSurveyVendors\TotalSuite\Foundation\Database\Model;

/**
 * @property int uid
 * @property string label
 * @property string color
 * @property int min
 * @property int max
 * @property string content
 */
class ScoringGrade extends Model
{
    /**
     * @var Scoring
     */
    protected $scoring;
    use Translatable;
    use HasRichText;

    public function __construct(Scoring $scoring, $attributes = [])
    {
        $attributes = static::applyTranslations($attributes);
        parent::__construct($attributes);
        $this->scoring = $scoring;
    }

    public static function getTranslatableAttributes(): array
    {
        return [
            'content.value',
            'label',
        ];
    }

    /**
     * @param  int  $percentage
     *
     * @return bool
     */
    public function check($percentage)
    {
        return ($percentage >= $this->min && $percentage <= $this->max);
    }

    /**
     * @param  EntryScore  $entryScore
     *
     * @return string
     */
    public function getCustomThankYouMessage(EntryScore $entryScore, Survey $survey)
    {
        if (is_string($this->content) && empty($this->content)) {
            $this->content = [];
        }
        $section = new Section($survey, $this->content);

        return $section->blocks->map(function (Block $block) {
            return $block->render();
        })->implode('');
    }


}
