<?php

namespace TotalSurvey\Extensions\Workflows;
! defined( 'ABSPATH' ) && exit();


use TotalSurvey\Events\Entries\OnEntryReceived;
use TotalSurvey\Extensions\Workflows\Tasks\CallWebHookWorkflow;
use TotalSurvey\Extensions\Workflows\Tasks\ExecuteHookWorkflow;
use TotalSurvey\Extensions\Workflows\Tasks\RedirectWorkflow;
use TotalSurvey\Extensions\Workflows\Tasks\SendEmailWorkflow;
use TotalSurvey\Services\WorkflowRegistry;
use TotalSurveyVendors\TotalSuite\Foundation\Exceptions\Exception;
use TotalSurveyVendors\TotalSuite\Foundation\View\Engine;
use TotalSurveyVendors\TotalSuite\Foundation\WordPress\Modules\Extension;

class Module extends Extension
{
    /**
     * @return mixed|void
     * @throws Exception
     */
    public function run()
    {
        $registry = WorkflowRegistry::instance();
        // events
        $registry->registerEvent('entry-received', 'Entry received', OnEntryReceived::class);

        // actions
        $registry->registerTask('send-email', 'Send email', SendEmailWorkflow::class);
        $registry->registerTask('execute-hook', 'Execute WordPress Hook', ExecuteHookWorkflow::class);
        $registry->registerTask('call-webhook', 'Call WebHook', CallWebHookWorkflow::class);
        $registry->registerTask('redirect', 'Redirect', RedirectWorkflow::class);
    }

    public static function view($name, array $data = [])
    {
        $engine = Engine::instance();
        $engine->setDirectory(__DIR__.DIRECTORY_SEPARATOR.'views');

        return $engine->render($name, $data);
    }
}
